import { IOperator } from "./IOperator";
export interface IFilterQuery {
    field: string;
    operator: IOperator;
    value: string | number | object | Array<string | number> | undefined | null;
}
export interface IPaginationQuery {
    page?: number;
    limit?: number;
    offset?: number;
    sortBy?: string;
    sortDirection?: 'asc' | 'desc';
}
export interface IPaginatedResponse<T> {
    data: T[];
    total: number;
    page: number;
    limit: number;
}
export interface IGenericFilterQuery {
    filters: IFilterQuery[];
    pagination: IPaginationQuery;
}
/**
 * Serializes IGenericFilterQuery into URL query parameters.
 * @param query The generic filter query.
 * @returns A string representing the serialized query parameters.
 */
export declare function serializeGenericFilterQuery(query: IGenericFilterQuery): string;
/**
 * Deserializes URL query parameters into IGenericFilterQuery.
 * @param queryString The URL query string.
 * @returns The deserialized generic filter query.
 */
export declare function deserializeGenericFilterQuery(queryString: string): IGenericFilterQuery;
export declare function convertFilterToQueryParams(filter: IFilterQuery | IFilterQuery[]): string;
export declare function parseQueryParamsToFilter(queryString: string): IFilterQuery[];
