export type HeaderRecord = Record<Extract<keyof IHttpHeaders, string>, string>;
export interface IHttpHeaders {
    'WWW-Authenticate'?: string;
    'Authorization'?: string;
    'Proxy-Authenticate'?: string;
    'Proxy-Authorization'?: string;
    'Age'?: number;
    'Cache-Control'?: 'public' | 'private' | 'no-cache' | 'no-store' | 'must-revalidate' | 'proxy-revalidate' | 'max-age=' | 'max-stale=' | 's-maxage=' | string;
    'Clear-Site-Data'?: '"cache"' | '"cookies"' | '"storage"' | '"executionContexts"' | '"*"' | string;
    'Expires'?: string;
    'Pragma'?: 'no-cache' | string;
    'Warning'?: string;
    'Accept-CH'?: string;
    'Accept-CH-Lifetime'?: number;
    'Critical-CH'?: string;
    'Last-Modified'?: string;
    'ETag'?: string;
    'If-Match'?: string;
    'If-None-Match'?: string;
    'If-Modified-Since'?: string;
    'If-Unmodified-Since'?: string;
    'Vary'?: string;
    'Connection'?: 'keep-alive' | 'close';
    'Keep-Alive'?: string;
    'Accept'?: string;
    'Accept-Encoding'?: 'gzip' | 'compress' | 'deflate' | 'br' | 'identity' | '*' | string;
    'Accept-Language'?: string;
    'Accept-Charset'?: string;
    'Expect'?: '100-continue' | string;
    'Max-Forwards'?: number;
    'Cookie'?: string;
    'Set-Cookie'?: string;
    'Access-Control-Allow-Origin'?: string;
    'Access-Control-Allow-Credentials'?: 'true' | 'false';
    'Access-Control-Allow-Headers'?: string;
    'Access-Control-Allow-Methods'?: string;
    'Access-Control-Expose-Headers'?: string;
    'Access-Control-Max-Age'?: number;
    'Access-Control-Request-Headers'?: string;
    'Access-Control-Request-Method'?: string;
    'Origin'?: string;
    'Timing-Allow-Origin'?: string;
    'Content-Disposition'?: string;
    'Content-Length'?: number;
    'Content-Type'?: string;
    'Content-Encoding'?: 'gzip' | 'compress' | 'deflate' | 'br' | 'identity' | string;
    'Content-Language'?: string;
    'Content-Location'?: string;
    'Content-Range'?: string;
    'Forwarded'?: string;
    'Via'?: string;
    'Location'?: string;
    'Refresh'?: string;
    'From'?: string;
    'Host'?: string;
    'Referer'?: string;
    'Referrer-Policy'?: 'no-referrer' | 'no-referrer-when-downgrade' | 'origin' | 'origin-when-cross-origin' | 'same-origin' | 'strict-origin' | 'strict-origin-when-cross-origin' | 'unsafe-url';
    'User-Agent'?: string;
    'Allow'?: string;
    'Server'?: string;
    'Cross-Origin-Embedder-Policy'?: 'require-corp' | 'unsafe-none';
    'Cross-Origin-Opener-Policy'?: 'same-origin' | 'same-origin-allow-popups' | 'unsafe-none';
    'Cross-Origin-Resource-Policy'?: 'same-site' | 'same-origin' | 'cross-origin';
    'Content-Security-Policy'?: string;
    'Content-Security-Policy-Report-Only'?: string;
    'Expect-CT'?: string;
    'Feature-Policy'?: string;
    'Strict-Transport-Security'?: string;
    'Upgrade-Insecure-Requests'?: '1';
    'X-Content-Type-Options'?: 'nosniff';
    'X-Download-Options'?: 'noopen';
    'X-Frame-Options'?: 'DENY' | 'SAMEORIGIN';
    'X-Permitted-Cross-Domain-Policies'?: 'none' | 'master-only' | 'by-content-type' | 'by-ftp-filename' | 'all';
    'X-Powered-By'?: string;
    'X-XSS-Protection'?: '0' | '1' | '1; mode=block' | '1; report=<reporting-uri>';
    'Transfer-Encoding'?: 'chunked' | 'compress' | 'deflate' | 'gzip' | 'identity';
    'TE'?: 'trailers' | 'compress' | 'deflate' | 'gzip' | 'trailers';
    'Sec-WebSocket-Accept'?: string;
    'Sec-WebSocket-Extensions'?: string;
    'Sec-WebSocket-Key'?: string;
    'Sec-WebSocket-Protocol'?: string;
    'Sec-WebSocket-Version'?: string;
    [key: string]: string | number | undefined;
}
